@@ -9,6 +9,8 @@ source "https://rubygems.org"
 
 gemspec
 
+gem "agent-context"
+
 # gem "io-event", git: "https://github.com/socketry/io-event.git"
 
 # In order to capture both code paths in coverage, we need to optionally load this gem:
@@ -33,6 +35,7 @@ group :test do
 	gem "sus-fixtures-async"
 	gem "sus-fixtures-console"
 	gem "sus-fixtures-time"
+	gem "sus-fixtures-benchmark"
 	
 	gem "bake-test"
 	gem "bake-test-external"
