@@ -22,7 +22,7 @@ describe Async::LimitedQueue do
 	end
 	
 	it "enqueues items up to a limit" do
-		items = Array.new(2) { rand(10) }
+		items = Array.new(2) {rand(10)}
 		reactor.async do
 			queue.enqueue(*items)
 		end
@@ -45,7 +45,7 @@ describe Async::LimitedQueue do
 		end
 		
 		10.times do
-			item = queue.dequeue
+			queue.dequeue
 			total_dequeued += 1
 			
 			expect(total_resumed).to be == total_dequeued
@@ -83,5 +83,22 @@ describe Async::LimitedQueue do
 			end
 		end
 	end
+
+	with "#close" do
+		it "signals tasks waiting to enqueue items when closed" do
+			queue.enqueue(:item1)
+
+			# This task will block as the queue is full:
+			waiting_task = reactor.async do
+				queue.enqueue(:item2)
+			end
+
+			queue.close
+
+			expect do
+				waiting_task.wait
+			end.to raise_exception(Async::Queue::ClosedError)
+		end
+	end
 end
 
