@@ -1,19 +1,19 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2018-2023, by Samuel Williams.
+# Copyright, 2018-2024, by Samuel Williams.
 
-require 'sus/fixtures/async'
-require 'async/notification'
+require "sus/fixtures/async"
+require "async/notification"
 
-require 'a_condition'
+require "async/a_condition"
 
 describe Async::Notification do
 	include Sus::Fixtures::Async::ReactorContext
 	
 	let(:notification) {subject.new}
 	
-	it 'should continue after notification is signalled' do
+	it "should continue after notification is signalled" do
 		sequence = []
 		
 		task = reactor.async do
@@ -47,5 +47,5 @@ describe Async::Notification do
 		]
 	end
 	
-	it_behaves_like ACondition
+	it_behaves_like Async::ACondition
 end
