@@ -75,11 +75,13 @@ describe Async::Task do
 	
 	with "#current?" do
 		it "can check if it is the currently running task" do
+			was_current = nil
+			
 			task = reactor.async do |task|
-				expect(task).to be(:current?)
-				sleep(0.1)
+				was_current = task.current?
 			end
 			
+			expect(was_current).to be == true
 			expect(task).not.to be(:current?)
 		end
 	end
@@ -124,7 +126,8 @@ describe Async::Task do
 			reactor.run do
 				expect do
 					reactor.async do |task|
-						expect(task).to receive(:warn).and_return(nil)
+						# Ensure the wait is executed before raising the exception:
+						task.yield
 						
 						raise "boom"
 					end.wait
@@ -154,19 +157,19 @@ describe Async::Task do
 		it "can consume exceptions" do
 			task = nil
 			
-			expect do
-				task = reactor.async do |task|
-					expect(task).to receive(:warn).and_return(nil)
-					
-					raise "boom"
-				end
-			end.not.to raise_exception
-			
 			reactor.run do
 				expect do
-					task.wait
-				end.to raise_exception(RuntimeError, message: be =~ /boom/)
+					task = reactor.async do |task|
+						expect(task).to receive(:warn).and_return(nil)
+						
+						raise "boom"
+					end
+				end.not.to raise_exception
 			end
+			
+			expect do
+				task.wait
+			end.to raise_exception(RuntimeError, message: be =~ /boom/)
 		end
 		
 		it "won't consume non-StandardError exceptions" do
@@ -276,9 +279,12 @@ describe Async::Task do
 		
 		it "can stop nested tasks with exception handling" do
 			reactor.run do
-				task = reactor.async do |task|
+				child = nil
+				
+				parent = reactor.async do |task|
 					child = task.async do |subtask|
-						sleep(1)
+						# Never comes back:
+						Fiber.scheduler.transfer
 					end
 					
 					begin
@@ -288,11 +294,15 @@ describe Async::Task do
 					end
 				end
 				
-				subtask = task.children.first
-				task.stop
+				# Ensure the parent has a chance to run:
+				Fiber.scheduler.yield
 				
-				expect(task.status).to be == :stopped
-				expect(subtask.status).to be == :stopped
+				parent.stop
+				parent.wait
+				expect(parent.status).to be == :stopped
+				
+				child.wait
+				expect(child.status).to be == :stopped
 			end
 		end
 		
@@ -501,6 +511,7 @@ describe Async::Task do
 		
 		it "can stop resumed task" do
 			items = [1, 2, 3]
+			value = nil
 			
 			reactor.run do
 				condition = Async::Condition.new
@@ -513,11 +524,11 @@ describe Async::Task do
 				end
 				
 				value = condition.wait # (2) value = Fiber.yield
-				expect(value).to be == 3
 				producer.stop # (5) [producer is resumed already] producer.stop
 			end
 			
 			expect(items).to be == [1, 2]
+			expect(value).to be == 3
 		end
 		
 		it "can stop a child task with transient children" do
@@ -706,14 +717,12 @@ describe Async::Task do
 		it "will propagate exceptions after async operation" do
 			error_task = innocent_task = nil
 			
-			error_task = reactor.async do |task|
-				task.yield
-				
+			error_task = reactor.async(finished: false) do |task|
 				raise "boom"
 			end
 			
-			innocent_task = reactor.async do |task|
-				expect{error_task.wait}.to raise_exception(RuntimeError, message: be =~ /boom/)
+			innocent_task = reactor.async(finished: false) do |task|
+				error_task.wait
 			end
 			
 			expect do
@@ -722,11 +731,15 @@ describe Async::Task do
 			
 			expect(error_task).to be(:finished?)
 			expect(innocent_task).to be(:finished?)
+			
+			expect do
+				innocent_task.wait
+			end.to raise_exception(RuntimeError, message: be =~ /boom/)
 		end
 
 		it "will not raise exception values returned by the task" do
 			error = StandardError.new
-			task = reactor.async { error }
+			task = reactor.async {error}
 			expect(task.wait).to be == error
 			expect(task.result).to be == error
 		end
